@@ -25,6 +25,9 @@
 #' otherwise, report the total variance explained by all the variables.
 #' @param nmodel a positive integer specifying the number of candidate models
 #' that the criterion selects. By default, \code{nmodel=3}.
+#' @param dataseed a vector of the seed that each simulation in Step 1 (see details) uses.
+#' The length of \code{dataseed} must be the same as \code{sim_times}.
+#' By default, \code{dataseed=1:sim_times}.
 #' @param runparallel logical. Use parallel programming based on \code{mclapply} function from R package \code{"parallel"} or not.
 #' Note that for Windows users, \code{mclapply} doesn't work, so please set \code{runparallel=FALSE} (default).
 #' @param mc.cores an integer giving the number of cores used for parallel programming.
@@ -105,7 +108,7 @@
 #' and the null model, i.e. the model with outcome and fixed covariates only.
 #'
 #' @references
-#' Yang Y, Lawson DJ. HTRX: an R package for learning non-contiguous haplotypes associated with a phenotype. bioRxiv (2022): 2022-11.29.518395.
+#' Yang Y, Lawson DJ. HTRX: an R package for learning non-contiguous haplotypes associated with a phenotype. Bioinformatics Advances 1.1 (2023): vbab038.
 #'
 #' Barrie, William, et al. "Genetic risk for Multiple Sclerosis originated in Pastoralist Steppe populations." bioRxiv (2022): 2022.09.23.509097.
 #'
@@ -145,11 +148,11 @@
 #' ## then perform HTRX using 2-step cross-validation in a single small example
 #' ## to compute additional variance explained by haplotypes
 #' ## If you want to compute total variance explained, please set gain=FALSE
-#' htrx_results <- do_cv(HTRX::example_data_nosnp[1:300,1:2],
-#'                       HTRX_matrix,train_proportion=0.5,
-#'                       sim_times=1,featurecap=4,usebinary=1,
-#'                       method="simple",criteria="BIC",
-#'                       gain=TRUE,runparallel=FALSE,verbose=TRUE)
+#' CV_results <- do_cv(HTRX::example_data_nosnp[1:300,1:2],
+#'                     HTRX_matrix,train_proportion=0.5,
+#'                     sim_times=1,featurecap=4,usebinary=1,
+#'                     method="simple",criteria="BIC",
+#'                     gain=TRUE,runparallel=FALSE,verbose=TRUE)
 #'
 #' #This result would be more precise when setting larger sim_times and featurecap
 NULL
@@ -158,14 +161,14 @@ NULL
 #' @export
 do_cv <- function(data_nosnp,featuredata,train_proportion=0.5,
                   sim_times=5,featurecap=dim(featuredata)[2],usebinary=1,
-                  method="simple",criteria="BIC",gain=TRUE,nmodel=3,
+                  method="simple",criteria="BIC",gain=TRUE,nmodel=3,dataseed=1:sim_times,
                   runparallel=FALSE,mc.cores=6,fold=10,kfoldseed=123,
                   returnwork=FALSE,verbose=FALSE){
 
   colnames(data_nosnp)[1]='outcome'
 
   #First step: obtain all the candidate models from running "sim_times" times simulation
-  candidate_models=lapply(1:sim_times,function(s){
+  candidate_models=lapply(dataseed,function(s){
     results=do_cv_step1(data_nosnp,featuredata,train_proportion,
                         featurecap=featurecap,usebinary=usebinary,
                         method=method,criteria=criteria,nmodel=nmodel,splitseed=s,
